@@ -17,7 +17,7 @@
  */
 package org.jboss.classfilewriter.test.bytecode.d;
 
-import junit.framework.Assert;
+import org.junit.Assert;
 
 import org.jboss.classfilewriter.code.CodeAttribute;
 import org.jboss.classfilewriter.test.bytecode.MethodTester;
@@ -33,6 +33,6 @@ public class DstoreTest {
         ca.dstore(0);
         ca.dload(0);
         ca.returnInstruction();
-        Assert.assertEquals(1.0, (double) mt.invoke());
+        Assert.assertEquals(1.0, mt.invoke(), 0);
     }
 }
